# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .map_config import MapConfig


class MapComponent(UniversalBaseModel):
    id: typing.Optional[str] = None
    user_id: typing_extensions.Annotated[str, FieldMetadata(alias="userId")]
    name: str
    config: MapConfig
    layer_ids: typing_extensions.Annotated[typing.Optional[typing.List[str]], FieldMetadata(alias="layerIds")] = (
        pydantic.Field(default=None)
    )
    """
    List of Layer IDs contained in this map.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
